netapp_ontap.resources.ntp_server API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.ntp_server`

Copyright © 2020 NetApp Inc. All rights reserved.

## Overview

You can use this API to add external NTP servers to a cluster, update the configuration, use NTP keys, and retrieve the current NTP server configuration.

## Adding an NTP server to a cluster

To add an NTP server to a cluster, issue a POST /cluster/ntp/servers request.

### Fields used for adding an NTP server

Except for the name of the NTP server (host name or IP address), which is specified by the server, all fields are optional:

- `version`
- `key`

###

If the key is provided in POST, `authentication_enabled` is set to `true` by default.

## Examples

### Adding an NTP server

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import NtpServer

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = NtpServer()
        resource.server = "time.nist.gov"
        resource.post(hydrate=True)
        print(resource)

### Adding an NTP server with an authentication key

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import NtpServer

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = NtpServer()
        resource.server = "time.nist.gov"
        resource.key.id = 10
        resource.post(hydrate=True)
        print(resource)

### Enabling a previously configured shared key (ID, type, and value) for an NTP server

A combination of key number or identifier (ID), type of key, and shared key value is created with /api/cluster/ntp/keys. This operation will validate the NTP authentication works.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import NtpServer

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = NtpServer(server="time.nist.gov")
        resource.key.id = 10
        resource.authentication_enabled = True
        resource.patch()

## Classes

`class NtpServer (*args, **kwargs)`

  Allows interaction with NtpServer objects on the host

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection(*args, connection: HostConnection = None, **kwargs) -> int`

    Retrieves the collection of external NTP time servers ONTAP uses for time adjustment and correction.

    ### Related ONTAP commands

    - `cluster time-service ntp server show`

    ### Learn more

    - `DOC /cluster/ntp/servers`

    Fetch a count of all objects of this type from the host.

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def delete_collection(*args, body: typing.Union = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Deletes an external NTP server used by ONTAP.

    ### Related ONTAP commands

    - `cluster time-service ntp server delete`

    ### Learn more

    - `DOC /cluster/ntp/servers`

    Delete all objects in a collection which match the given query.

    All records on the host which match the query will be deleted.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to delete the collection of bars for a particular foo, the foo.name value should be passed.
    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def find(*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves the collection of external NTP time servers ONTAP uses for time adjustment and correction.

    ### Related ONTAP commands

    - `cluster time-service ntp server show`

    ### Learn more

    - `DOC /cluster/ntp/servers`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection(*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> typing.Iterable`

    Retrieves the collection of external NTP time servers ONTAP uses for time adjustment and correction.

    ### Related ONTAP commands

    - `cluster time-service ntp server show`

    ### Learn more

    - `DOC /cluster/ntp/servers`

    Fetch a list of all objects of this type from the host.

    This is a lazy fetch, making API calls only as necessary when the result of this call is iterated over. For instance, if max_records is set to 5, then iterating over the collection causes an API call to be sent to the server once for every 5 records. If the client stops iterating before getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection(body: dict, *args, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Updates the configuration of an NTP server used by the ONTAP cluster after validation. Patchable fields are: * `version` * `key.id` * `authentication_enabled` If `authentication_enabled` is modified to `false`, the associated NTP key is removed from the server instance. If `authentication_enabled` is modified to `true`, you must provide an NTP key ID in the PATCH body.

    ### Related ONTAP commands

    - `cluster time-service ntp server modify`

    ### Learn more

    - `DOC /cluster/ntp/servers`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def delete(self, body: typing.Union = None, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Deletes an external NTP server used by ONTAP.

    ### Related ONTAP commands

    - `cluster time-service ntp server delete`

    ### Learn more

    - `DOC /cluster/ntp/servers`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves the configuration of an external NTP server used by ONTAP.

    ### Related ONTAP commands

    - `cluster time-service ntp server show`

    ### Learn more

    - `DOC /cluster/ntp/servers`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def patch(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Updates the configuration of an NTP server used by the ONTAP cluster after validation. Patchable fields are: * `version` * `key.id` * `authentication_enabled` If `authentication_enabled` is modified to `false`, the associated NTP key is removed from the server instance. If `authentication_enabled` is modified to `true`, you must provide an NTP key ID in the PATCH body.

    ### Related ONTAP commands

    - `cluster time-service ntp server modify`

    ### Learn more

    - `DOC /cluster/ntp/servers`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Validates the provided external NTP time server for usage and configures ONTAP so that all nodes in the cluster use it. The required fields are: * `server`

    ### Default property values

    If not specified in POST, the following default property values are assigned: * `version` - auto * `key` - not set

    ###

    If the key is provided in POST, `authentication_enabled` is set to `true` by default.

    ### Related ONTAP commands

    - `cluster time-service ntp server create`

    ### Learn more

    - `DOC /cluster/ntp/servers`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class NtpServerSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the NtpServer object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `authentication_enabled GET PATCH`

    Set NTP symmetric authentication on (true) or off (false).

    Example: true

  `key GET POST PATCH`

    The key field of the ntp_server.

  `links GET`

    The links field of the ntp_server.

  `server GET POST`

    NTP server host name, IPv4, or IPv6 address.

    Example: time.nist.gov

  `version GET POST PATCH`

    NTP protocol version for server. Valid versions are 3, 4, or auto.

    Valid choices:

    - 3
    - 4
    - auto